==> monaco-vscode-user-data-profile-service-override-5.3.0.tgz: package/vscode/src/vs/platform/userDataProfile/common/userDataProfileStorageService.js <==
import { __decorate, __param } from 'vscode/external/tslib/tslib.es6.js';
import { Disposable, isDisposable } from 'vscode/vscode/vs/base/common/lifecycle';
import { Storage } from 'vscode/vscode/vs/base/parts/storage/common/storage';
import { AbstractStorageService } from 'vscode/vscode/vs/platform/storage/common/storage';
import { IStorageService } from 'vscode/vscode/vs/platform/storage/common/storage.service';
import 'vscode/vscode/vs/base/common/event';
import 'vscode/vscode/vs/platform/userDataProfile/common/userDataProfile';

let AbstractUserDataProfileStorageService = class AbstractUserDataProfileStorageService extends Disposable {
    constructor(storageService) {
        super();
        this.storageService = storageService;
    }
    async readStorageData(profile) {
        return this.withProfileScopedStorageService(profile, async (storageService) => this.getItems(storageService));
    }
    async updateStorageData(profile, data, target) {
        return this.withProfileScopedStorageService(profile, async (storageService) => this.writeItems(storageService, data, target));
    }
    async withProfileScopedStorageService(profile, fn) {
        if (this.storageService.hasScope(profile)) {
            return fn(this.storageService);
        }
        const storageDatabase = await this.createStorageDatabase(profile);
        const storageService = ( new StorageService(storageDatabase));
        try {
            await storageService.initialize();
            const result = await fn(storageService);
            await storageService.flush();
            return result;
        }
        finally {
            storageService.dispose();
            await this.closeAndDispose(storageDatabase);
        }
    }
    getItems(storageService) {
        const result = ( new Map());
        const populate = (target) => {
            for (const key of ( storageService.keys(0, target))) {
                result.set(key, { value: storageService.get(key, 0 ), target });
            }
        };
        populate(0 );
        populate(1 );
        return result;
    }
    writeItems(storageService, items, target) {
        storageService.storeAll(( Array.from(items.entries()).map(
            ([key, value]) => ({ key, value, scope: 0 , target })
        )), true);
    }
    async closeAndDispose(storageDatabase) {
        try {
            await storageDatabase.close();
        }
        finally {
            if (isDisposable(storageDatabase)) {
                storageDatabase.dispose();
            }
        }
    }
};
AbstractUserDataProfileStorageService = ( __decorate([
    ( __param(0, IStorageService))
], AbstractUserDataProfileStorageService));
class StorageService extends AbstractStorageService {
    constructor(profileStorageDatabase) {
        super({ flushInterval: 100 });
        this.profileStorage = this._register(( new Storage(profileStorageDatabase)));
    }
    doInitialize() {
        return this.profileStorage.init();
    }
    getStorage(scope) {
        return scope === 0  ? this.profileStorage : undefined;
    }
    getLogDetails() { return undefined; }
    async switchToProfile() { }
    async switchToWorkspace() { }
    hasScope() { return false; }
}

export { AbstractUserDataProfileStorageService };

==> monaco-vscode-user-data-profile-service-override-6.0.3.tgz: package/vscode/src/vs/platform/userDataProfile/common/userDataProfileStorageService.js <==
import { __decorate, __param } from 'vscode/external/tslib/tslib.es6.js';
import { Disposable, isDisposable } from 'vscode/vscode/vs/base/common/lifecycle';
import { Storage } from 'vscode/vscode/vs/base/parts/storage/common/storage';
import { StorageScope, StorageTarget, AbstractStorageService } from 'vscode/vscode/vs/platform/storage/common/storage';
import { IStorageService } from 'vscode/vscode/vs/platform/storage/common/storage.service';
import 'vscode/vscode/vs/base/common/event';
import 'vscode/vscode/vs/platform/userDataProfile/common/userDataProfile';

let AbstractUserDataProfileStorageService = class AbstractUserDataProfileStorageService extends Disposable {
    constructor(storageService) {
        super();
        this.storageService = storageService;
    }
    async readStorageData(profile) {
        return this.withProfileScopedStorageService(profile, async (storageService) => this.getItems(storageService));
    }
    async updateStorageData(profile, data, target) {
        return this.withProfileScopedStorageService(profile, async (storageService) => this.writeItems(storageService, data, target));
    }
    async withProfileScopedStorageService(profile, fn) {
        if (this.storageService.hasScope(profile)) {
            return fn(this.storageService);
        }
        const storageDatabase = await this.createStorageDatabase(profile);
        const storageService = ( new StorageService(storageDatabase));
        try {
            await storageService.initialize();
            const result = await fn(storageService);
            await storageService.flush();
            return result;
        }
        finally {
            storageService.dispose();
            await this.closeAndDispose(storageDatabase);
        }
    }
    getItems(storageService) {
        const result = ( new Map());
        const populate = (target) => {
            for (const key of ( storageService.keys(StorageScope.PROFILE, target))) {
                result.set(key, { value: storageService.get(key, StorageScope.PROFILE), target });
            }
        };
        populate(StorageTarget.USER);
        populate(StorageTarget.MACHINE);
        return result;
    }
    writeItems(storageService, items, target) {
        storageService.storeAll(( Array.from(items.entries()).map(([key, value]) => ({ key, value, scope: StorageScope.PROFILE, target }))), true);
    }
    async closeAndDispose(storageDatabase) {
        try {
            await storageDatabase.close();
        }
        finally {
            if (isDisposable(storageDatabase)) {
                storageDatabase.dispose();
            }
        }
    }
};
AbstractUserDataProfileStorageService = ( __decorate([
    ( __param(0, IStorageService))
], AbstractUserDataProfileStorageService));
class StorageService extends AbstractStorageService {
    constructor(profileStorageDatabase) {
        super({ flushInterval: 100 });
        this.profileStorage = this._register(( new Storage(profileStorageDatabase)));
    }
    doInitialize() {
        return this.profileStorage.init();
    }
    getStorage(scope) {
        return scope === StorageScope.PROFILE ? this.profileStorage : undefined;
    }
    getLogDetails() { return undefined; }
    async switchToProfile() { }
    async switchToWorkspace() { }
    hasScope() { return false; }
}

export { AbstractUserDataProfileStorageService };
